==> org.eclipse.emf.eef.mapping.edit.source_1.1.1.201206051542.jar: org/eclipse/emf/eef/mapping/navigation/providers/NavigationMessages.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2012 Obeo.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.emf.eef.mapping.navigation.providers;

import org.eclipse.osgi.util.NLS;

/**
 * @author <a href="mailto:nathalie.lepine@obeo.fr">Nathalie Lepine</a>
 * 
 */
public class NavigationMessages extends NLS {
	
	private static final String BUNDLE_NAME = "org.eclipse.emf.eef.mapping.navigation.providers.navigationMessages"; //$NON-NLS-1$

	
	public static String ModelNavigationPropertiesEditionPart_PropertiesGroupLabel;

	
	public static String SimpleModelNavigationPropertiesEditionPart_PropertiesGroupLabel;


	
	public static String ModelNavigation_ReadOnly;

	
	public static String ModelNavigation_Part_Title;

	
	public static String SimpleModelNavigation_ReadOnly;

	
	public static String SimpleModelNavigation_Part_Title;


	
	public static String SimpleModelNavigationPropertiesEditionPart_IndexLabel;

	
	public static String SimpleModelNavigationPropertiesEditionPart_FeatureLabel;

	
	public static String SimpleModelNavigationPropertiesEditionPart_DiscriminatorTypeLabel;


	
	public static String PropertiesEditionPart_DocumentationLabel;

	
	public static String PropertiesEditionPart_IntegerValueMessage;

	
	public static String PropertiesEditionPart_FloatValueMessage;

	
	public static String PropertiesEditionPart_ShortValueMessage;

	
	public static String PropertiesEditionPart_LongValueMessage;

	
	public static String PropertiesEditionPart_ByteValueMessage;

	
	public static String PropertiesEditionPart_BigIntegerValueMessage;

	
	public static String PropertiesEditionPart_BigDecimalValueMessage;

	
	public static String PropertiesEditionPart_DoubleValueMessage;

	
	public static String PropertiesEditionPart_PropertiesGroupLabel;

	
	public static String PropertiesEditionPart_RequiredFeatureMessage;

	
	public static String PropertiesEditionPart_AddTableViewerLabel;

	
	public static String PropertiesEditionPart_EditTableViewerLabel;

	
	public static String PropertiesEditionPart_RemoveTableViewerLabel;

	
	public static String PropertiesEditionPart_AddListViewerLabel;

	
	public static String PropertiesEditionPart_RemoveListViewerLabel;

	// Start of user code for additionnal NLS Constants
	
	// End of user code

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, NavigationMessages.class);
	}

	
	private NavigationMessages() {
		//protect instanciation
	}
}

==> org.eclipse.emf.eef.mapping.edit.source_1.5.1.201601141612.jar: org/eclipse/emf/eef/mapping/navigation/providers/NavigationMessages.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2012 Obeo.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.emf.eef.mapping.navigation.providers;

import org.eclipse.osgi.util.NLS;

/**
 * @author <a href="mailto:nathalie.lepine@obeo.fr">Nathalie Lepine</a>
 * 
 */
public class NavigationMessages extends NLS {
	
	private static final String BUNDLE_NAME = "org.eclipse.emf.eef.mapping.navigation.providers.navigationMessages"; //$NON-NLS-1$

	
	public static String ModelNavigationPropertiesEditionPart_PropertiesGroupLabel;

	
	public static String SimpleModelNavigationPropertiesEditionPart_PropertiesGroupLabel;

	
	public static String DeclarativeNavigationStepPropertiesEditionPart_PropertiesGroupLabel;

	
	public static String JavaDeclarationStepInitializerPropertiesEditionPart_PropertiesGroupLabel;

	
	public static String JavaBodyStepInitializerPropertiesEditionPart_PropertiesGroupLabel;


	
	public static String ModelNavigation_ReadOnly;

	
	public static String ModelNavigation_Part_Title;

	
	public static String SimpleModelNavigation_ReadOnly;

	
	public static String SimpleModelNavigation_Part_Title;

	
	public static String DeclarativeNavigationStep_ReadOnly;

	
	public static String DeclarativeNavigationStep_Part_Title;

	
	public static String JavaDeclarationStepInitializer_ReadOnly;

	
	public static String JavaDeclarationStepInitializer_Part_Title;

	
	public static String JavaBodyStepInitializer_ReadOnly;

	
	public static String JavaBodyStepInitializer_Part_Title;


	
	public static String SimpleModelNavigationPropertiesEditionPart_IndexLabel;

	
	public static String SimpleModelNavigationPropertiesEditionPart_FeatureLabel;

	
	public static String SimpleModelNavigationPropertiesEditionPart_DiscriminatorTypeLabel;

	
	public static String DeclarativeNavigationStepPropertiesEditionPart_IndexLabel;

	
	public static String DeclarativeNavigationStepPropertiesEditionPart_FeatureLabel;

	
	public static String DeclarativeNavigationStepPropertiesEditionPart_DiscriminatorTypeLabel;

	
	public static String JavaDeclarationStepInitializerPropertiesEditionPart_QualifiedClassLabel;

	
	public static String JavaDeclarationStepInitializerPropertiesEditionPart_MethodFilterLabel;

	
	public static String JavaDeclarationStepInitializerPropertiesEditionPart_StaticMethodLabel;

	
	public static String JavaBodyStepInitializerPropertiesEditionPart_BodyLabel;


	
	public static String PropertiesEditionPart_DocumentationLabel;

	
	public static String PropertiesEditionPart_IntegerValueMessage;

	
	public static String PropertiesEditionPart_FloatValueMessage;

	
	public static String PropertiesEditionPart_ShortValueMessage;

	
	public static String PropertiesEditionPart_LongValueMessage;

	
	public static String PropertiesEditionPart_ByteValueMessage;

	
	public static String PropertiesEditionPart_BigIntegerValueMessage;

	
	public static String PropertiesEditionPart_BigDecimalValueMessage;

	
	public static String PropertiesEditionPart_DoubleValueMessage;

	
	public static String PropertiesEditionPart_PropertiesGroupLabel;

	
	public static String PropertiesEditionPart_RequiredFeatureMessage;

	
	public static String PropertiesEditionPart_AddTableViewerLabel;

	
	public static String PropertiesEditionPart_EditTableViewerLabel;

	
	public static String PropertiesEditionPart_RemoveTableViewerLabel;

	
	public static String PropertiesEditionPart_AddListViewerLabel;

	
	public static String PropertiesEditionPart_RemoveListViewerLabel;

	// Start of user code for additionnal NLS Constants
	
	// End of user code

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, NavigationMessages.class);
	}

	
	private NavigationMessages() {
		//protect instanciation
	}
}
